==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-mount/translations/mount_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>إعدادات الوسيط المنفصل</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>السلوك</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>أبثِق قائمة</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="44"/>
        <source>Show info</source>
        <translation>اعرض معلوماته</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="45"/>
        <location filename="../configuration.cpp" line="50"/>
        <source>Do nothing</source>
        <translation>لا تفعل شيئا</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="51"/>
        <source>Eject All Optical Drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>وُصل الجهاز &lt;b&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>أُزيل الجهاز &lt;b&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="153"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>فشل ضمّ &lt;b&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/b&gt;:‏ %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="174"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>فشل إلغاء ضمّ &lt;strong&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/strong&gt;:‏ %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>لا أجهزة متوفرة</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-mount/translations/mount_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>إعدادات الوسيط المنفصل</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>السلوك</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation>عند توصيل جهاز:</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt; &lt;head/&gt; &lt;body&gt; &lt;p&gt; قم بتشغيل الإجراء التالي عند الضغط على اختصار الإخراج (&lt;span style = &quot;font-weight: 600؛&quot;&gt; XF86Eject &lt;/span&gt; افتراضيًا) &lt;/p&gt; &lt;/body&gt; &lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation>عند الضغط على زر الإخراج:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="60"/>
        <source>Popup menu</source>
        <translation>أبثِق قائمة</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="61"/>
        <source>Show info</source>
        <translation>اعرض معلوماته</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="62"/>
        <location filename="../configuration.cpp" line="64"/>
        <source>Do nothing</source>
        <translation>لا تفعل شيئا</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="65"/>
        <source>Eject All Optical Drives</source>
        <translation>أخرج جميع محركات الأقراص الضوئية</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>وُصل الجهاز &lt;b&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>أُزيل الجهاز &lt;b&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation>أخرج جميع محركات الأقراص الضوئية</translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>إدارة الوسائط / الأجهزة القابلة للإزالة: لا يمكن تسجيل الاختصار العام &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation>إخراج الوسائط القابلة للإزالة</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="156"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>فشل ضمّ &lt;b&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/b&gt;:‏ %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="158"/>
        <location filename="../menudiskitem.cpp" line="179"/>
        <source>Removable media/devices manager</source>
        <translation>مدير الأجهزة/الوسائط المنفصلة</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="177"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>فشل إلغاء ضمّ &lt;strong&gt;&lt;nobr&gt;”%1“&lt;/nobr&gt;&lt;/strong&gt;:‏ %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="67"/>
        <source>No devices are available</source>
        <translation>لا أجهزة متوفرة</translation>
    </message>
</context>
</TS>
